@@ -11,38 +11,105 @@
 #'
 #' @details
 #'
-#'   We recommend reading this documentation on
-#'   <https://pkg.mitchelloharawild.com/distributional/>, where the math
-#'   will render nicely.
+#' `r pkgdown_doc_link("dist_gumbel")`
 #'
 #'   In the following, let \eqn{X} be a Gumbel random variable with location
-#'   parameter  `mu` = \eqn{\mu}, scale parameter `sigma` = \eqn{\sigma}.
+#'   parameter  `alpha` = \eqn{\alpha} and scale parameter `scale` = \eqn{\sigma}.
 #'
 #'   **Support**: \eqn{R}, the set of all real numbers.
 #'
-#'   **Mean**: \eqn{\mu + \sigma\gamma}, where \eqn{\gamma} is Euler's
-#'   constant, approximately equal to 0.57722.
+#'   **Mean**: 
+#'   
+#'   \deqn{
+#'     E(X) = \alpha + \sigma\gamma
+#'   }{
+#'     E(X) = alpha + sigma*gamma
+#'   }
+#'   
+#'   where \eqn{\gamma} is the Euler-Mascheroni constant, 
+#'   approximately equal to 0.5772157.
 #'
-#'   **Median**: \eqn{\mu - \sigma\ln(\ln 2)}{\mu - \sigma ln(ln 2)}.
+#'   **Variance**: 
+#'   
+#'   \deqn{
+#'     \textrm{Var}(X) = \frac{\pi^2 \sigma^2}{6}
+#'   }{
+#'     Var(X) = (pi^2 * sigma^2) / 6
+#'   }
 #'
-#'   **Variance**: \eqn{\sigma^2 \pi^2 / 6}.
+#'   **Skewness**: 
+#'   
+#'   \deqn{
+#'     \textrm{Skew}(X) = \frac{12\sqrt{6}\zeta(3)}{\pi^3} \approx 1.1395
+#'   }{
+#'     Skew(X) = (12*sqrt(6)*zeta(3)) / pi^3
+#'   }
+#'   
+#'   where \eqn{\zeta(3)} is Apery's constant, 
+#'   approximately equal to 1.2020569. Note that skewness is independent 
+#'   of the distribution parameters.
+#'
+#'   **Kurtosis (excess)**: 
+#'   
+#'   \deqn{
+#'     \textrm{Kurt}(X) = \frac{12}{5} = 2.4
+#'   }{
+#'     Kurt(X) = 12/5
+#'   }
+#'   
+#'   Note that excess kurtosis is independent of the distribution parameters.
+#'
+#'   **Median**: 
+#'   
+#'   \deqn{
+#'     \textrm{Median}(X) = \alpha - \sigma\ln(\ln 2)
+#'   }{
+#'     Median(X) = alpha - sigma*ln(ln(2))
+#'   }
 #'
 #'   **Probability density function (p.d.f)**:
 #'
-#'   \deqn{f(x) = \sigma ^ {-1} \exp[-(x - \mu) / \sigma]%
-#'         \exp\{-\exp[-(x - \mu) / \sigma] \}}{%
-#'        f(x) = (1 / \sigma) exp[-(x - \mu) / \sigma]%
-#'         exp{-exp[-(x - \mu) / \sigma]}}
+#'   \deqn{
+#'     f(x) = \frac{1}{\sigma} \exp\left[-\frac{x - \alpha}{\sigma}\right]
+#'            \exp\left\{-\exp\left[-\frac{x - \alpha}{\sigma}\right]\right\}
+#'   }{
+#'     f(x) = (1/sigma) * exp[-(x - alpha)/sigma] * exp(-exp[-(x - alpha)/sigma])
+#'   }
+#'   
 #'   for \eqn{x} in \eqn{R}, the set of all real numbers.
 #'
 #'   **Cumulative distribution function (c.d.f)**:
 #'
-#'   In the \eqn{\xi = 0} (Gumbel) special case
-#'   \deqn{F(x) = \exp\{-\exp[-(x - \mu) / \sigma] \}}{%
-#'         F(x) = exp{ - exp[-(x - \mu) / \sigma]} }
+#'   \deqn{
+#'     F(x) = \exp\left\{-\exp\left[-\frac{x - \alpha}{\sigma}\right]\right\}
+#'   }{
+#'     F(x) = exp(-exp[-(x - alpha)/sigma])
+#'   }
+#'   
 #'   for \eqn{x} in \eqn{R}, the set of all real numbers.
 #'
-#' @seealso [actuar::Gumbel]
+#'   **Quantile function (inverse c.d.f)**:
+#'
+#'   \deqn{
+#'     F^{-1}(p) = \alpha - \sigma \ln(-\ln p)
+#'   }{
+#'     F^(-1)(p) = alpha - sigma * ln(-ln(p))
+#'   }
+#'   
+#'   for \eqn{p} in (0, 1).
+#'
+#'   **Moment generating function (m.g.f)**:
+#'
+#'   \deqn{
+#'     E(e^{tX}) = \Gamma(1 - \sigma t) e^{\alpha t}
+#'   }{
+#'     E(e^(tX)) = Gamma(1 - sigma*t) * e^(alpha*t)
+#'   }
+#'   
+#'   for \eqn{\sigma t < 1}, where \eqn{\Gamma} is the gamma function.
+#'
+#' @seealso [actuar::Gumbel], [actuar::dgumbel()], [actuar::pgumbel()], 
+#'   [actuar::qgumbel()], [actuar::rgumbel()], [actuar::mgumbel()]
 #'
 #' @examples
 #' dist <- dist_gumbel(alpha = c(0.5, 1, 1.5, 3), scale = c(2, 2, 3, 4))
@@ -125,8 +192,9 @@ covariance.dist_gumbel <- function(x, ...){
 
 #' @export
 skewness.dist_gumbel <- function(x, ...) {
-  zeta3 <- 1.20205690315959401459612
-  (12 * sqrt(6) * zeta3) / pi^3
+  1.13954709940465
+  # zeta3 <- 1.20205690315959401459612
+  # (12 * sqrt(6) * zeta3) / pi^3
 }
 
 #' @export
